
require('dotenv/config');
const express = require('express');
const cors = require('cors');
const bearerToken = require('express-bearer-token');
const {orbbyteRequests} = require('./orbbyteTransfers/requests.js');
const {customRequests} = require('./customRequests');
const https = require('https');
const http = require('http');
const app = express();
const server = http.createServer(app);

const PORT_HTTP = 3210;
const PORT_HTTPS = 3211;

app.use(cors());
app.use(express.urlencoded({ extended: true }));
app.use(express.json());
app.use(bearerToken());
app.use(function (req, res, next) {
    if(req.token !== process.env.BEARER && req.url !== '/' ) {
        res.json({statusCode: 403, message: 'Unauthorized request'});
    }

    next();
});

customRequests(app, server);
orbbyteRequests(app);

function startServer() {
    server.listen(PORT_HTTP, () => console.log('Go to http://localhost:' + PORT_HTTP + ' to view API docs'));
}

function startServerHttps() {
    const httpsServer = https.createServer(app);
    httpsServer.listen(PORT_HTTPS, () => console.log('HTTPS running on http://localhost:' + PORT_HTTPS));
}

startServer();
startServerHttps();